call.moment: Calculating the expectation and variance of the offspring's genotype conditional on parental genotypes.
Description
The expectation and variance are calculated with respect to parental genotypes at a single marker under the null distribution of parental random transmission using Mendel's laws.
Usage
call.moment(father,mother)
Arguments
father
indicates the father's genotype, coded as 0, 1 and 2.
mother
indicates the mother's genotype, coded as 0, 1 and 2.
Value
mean
expecation of the offspring's genotype.
var
variance of the offspring's genotype.
References
Guo W , Shugart YY, Detecting Rare Variants for Quantitative Traits Using Nuclear Families (manuscript).